@@ -5,10 +5,11 @@ use utf8;
 
 package Dist::Zilla::Plugin::OSPrereqs;
 # ABSTRACT: List prereqs conditional on operating system
-our $VERSION = '0.005'; # VERSION
+
+our $VERSION = '0.006';
 
 use Moose;
-use List::AllUtils 'first';
+use List::Util 1.33 'first';
 use namespace::autoclean;
 
 with 'Dist::Zilla::Role::InstallTool', 'Dist::Zilla::Role::MetaProvider';
@@ -162,7 +163,7 @@ Dist::Zilla::Plugin::OSPrereqs - List prereqs conditional on operating system
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -220,7 +221,7 @@ changes how it generates install scripts.
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/dist-zilla-plugin-osprereqs/issues>.
+at L<https://github.com/dagolden/Dist-Zilla-Plugin-OSPrereqs/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -228,9 +229,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/dist-zilla-plugin-osprereqs>
+L<https://github.com/dagolden/Dist-Zilla-Plugin-OSPrereqs>
 
-  git clone https://github.com/dagolden/dist-zilla-plugin-osprereqs.git
+  git clone https://github.com/dagolden/Dist-Zilla-Plugin-OSPrereqs.git
 
 =head1 AUTHOR
 
@@ -238,6 +239,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Dave Rolsky Ioan Rogers Karen Etheridge Steven Haryanto (on PC, Bandung)
+
 =over 4
 
 =item *
